@@ -17,14 +17,14 @@
 
  You should have received a copy of the GNU General Public License
  along with VRender; if not, write to the Free Software Foundation, Inc.,
- 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 /****************************************************************************
 
- Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.4.
+ This file is part of the QGLViewer library version 2.5.3.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -42,55 +42,15 @@
 
 *****************************************************************************/
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 #include "Primitive.h"
 #include "AxisAlignedBox.h"
 #include "PrimitivePositioning.h"
 #include "math.h"
+#include <algorithm>
 #include "Vector2.h"
 
+#include <algorithm>
+
 using namespace vrender ;
 using namespace std ;
 
@@ -168,7 +128,7 @@ int PrimitivePositioning::computeRelativePosition(const Polygone *P,const Segmen
 
 	double t1,t2 ;
 
-	for(int i=0;i<P->nbVertices();++i)
+        for(unsigned int i=0;i<P->nbVertices();++i)
 		if(intersectSegments_XY(Vector2(S->vertex(0)),Vector2(S->vertex(1)),Vector2(P->vertex(i)),Vector2(P->vertex(i+1)),_EPS,t1,t2))
 			intersections.push_back(t1) ;
 
@@ -180,8 +140,8 @@ int PrimitivePositioning::computeRelativePosition(const Polygone *P,const Segmen
 
 	for(unsigned int j=0;j<intersections.size();++j)
 	{
-		tmin = min(tmin,intersections[j]) ;
-		tmax = max(tmax,intersections[j]) ;
+		tmin = std::min(tmin,intersections[j]) ;
+		tmax = std::max(tmax,intersections[j]) ;
 	}
 
 	if(tmax - tmin < 2*_EPS)
@@ -311,8 +271,8 @@ bool PrimitivePositioning::pointOutOfPolygon_XY(const Vector3& P,const Polygone
 
 		double Z = (q1-p)^(q2-p) ;
 
-		MinZ = min(Z,MinZ) ;
-		MaxZ = max(Z,MaxZ) ;
+		MinZ = std::min(Z,MinZ) ;
+		MaxZ = std::max(Z,MaxZ) ;
 	}
 
 	if((MaxZ <= -I_EPS*I_EPS)||(MinZ >= I_EPS*I_EPS))	// the point is inside the polygon
@@ -392,8 +352,8 @@ bool PrimitivePositioning::intersectSegments_XY(const Vector2& P1,const Vector2&
 			return false ;
 		}
 
-		double tPQM = max(tP1,tQ1) ;
-		double tPQm = min(tP1,tQ1) ;
+		double tPQM = std::max(tP1,tQ1) ;
+		double tPQm = std::min(tP1,tQ1) ;
 
 		if(( tPQM < -I_EPS) || (tPQm > 1.0+I_EPS))
 			return false ;
@@ -447,7 +407,7 @@ gpc_polygon PrimitivePositioning::createGPCPolygon_XY(const Polygone *P)
 	gpc_p_verts->num_vertices = P->nbVertices() ;
 	gpc_p_verts->vertex = new gpc_vertex[P->nbVertices()] ;
 
-	for(int i=0;i<P->nbVertices();++i)
+        for(unsigned int i=0;i<P->nbVertices();++i)
 	{
 		gpc_p_verts->vertex[i].x = P->vertex(i).x() ;
 		gpc_p_verts->vertex[i].y = P->vertex(i).y() ;
