@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2011 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.17.
+ This file is part of the QGLViewer library version 2.5.3.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,9 +22,8 @@
 
 #include "constrainedFrame.h"
 
-#if QT_VERSION >= 0x040000
-# include <QKeyEvent>
-#endif
+#include <QKeyEvent>
+#include <QGLViewer/manipulatedCameraFrame.h>
 
 using namespace qglviewer;
 using namespace std;
@@ -32,25 +31,25 @@ using namespace std;
 AxisPlaneConstraint::Type Viewer::nextTranslationConstraintType(const AxisPlaneConstraint::Type& type)
 {
   switch (type)
-    {
-    case AxisPlaneConstraint::FREE  : return AxisPlaneConstraint::PLANE; break;
-    case AxisPlaneConstraint::PLANE : return AxisPlaneConstraint::AXIS;  break;
-    case AxisPlaneConstraint::AXIS  : return AxisPlaneConstraint::FORBIDDEN;  break;
-    case AxisPlaneConstraint::FORBIDDEN : return AxisPlaneConstraint::FREE; break;
-    default : return AxisPlaneConstraint::FREE;
-    }
+	{
+	case AxisPlaneConstraint::FREE  : return AxisPlaneConstraint::PLANE; break;
+	case AxisPlaneConstraint::PLANE : return AxisPlaneConstraint::AXIS;  break;
+	case AxisPlaneConstraint::AXIS  : return AxisPlaneConstraint::FORBIDDEN;  break;
+	case AxisPlaneConstraint::FORBIDDEN : return AxisPlaneConstraint::FREE; break;
+	default : return AxisPlaneConstraint::FREE;
+	}
 }
 
 AxisPlaneConstraint::Type Viewer::nextRotationConstraintType(const AxisPlaneConstraint::Type& type)
 {
   switch (type)
-    {
-    case AxisPlaneConstraint::FREE  : return AxisPlaneConstraint::AXIS; break;
-    case AxisPlaneConstraint::AXIS  : return AxisPlaneConstraint::FORBIDDEN;  break;
-    case AxisPlaneConstraint::PLANE :
-    case AxisPlaneConstraint::FORBIDDEN : return AxisPlaneConstraint::FREE; break;
-    default : return AxisPlaneConstraint::FREE;
-    }
+	{
+	case AxisPlaneConstraint::FREE  : return AxisPlaneConstraint::AXIS; break;
+	case AxisPlaneConstraint::AXIS  : return AxisPlaneConstraint::FORBIDDEN;  break;
+	case AxisPlaneConstraint::PLANE :
+	case AxisPlaneConstraint::FORBIDDEN : return AxisPlaneConstraint::FREE; break;
+	default : return AxisPlaneConstraint::FREE;
+	}
 }
 
 void Viewer::changeConstraint()
@@ -80,28 +79,20 @@ void Viewer::init()
   setManipulatedFrame(frame);
   frame->setConstraint(constraints[activeConstraint]);
 
-#if QT_VERSION < 0x040000
-  // Preserve CAMERA bindings, see setHandlerKeyboardModifiers documentation.
-  setHandlerKeyboardModifiers(QGLViewer::CAMERA, Qt::AltButton);
-  // The frames can be move without any key pressed
-  setHandlerKeyboardModifiers(QGLViewer::FRAME, Qt::NoButton);
-  // The camera can always be moved with the Control key.
-  setHandlerKeyboardModifiers(QGLViewer::CAMERA, Qt::ControlButton);
+  setMouseBinding(Qt::AltModifier, Qt::LeftButton, QGLViewer::CAMERA, QGLViewer::ROTATE);
+  setMouseBinding(Qt::AltModifier, Qt::RightButton, QGLViewer::CAMERA, QGLViewer::TRANSLATE);
+  setMouseBinding(Qt::AltModifier, Qt::MidButton, QGLViewer::CAMERA, QGLViewer::ZOOM);
+  setWheelBinding(Qt::AltModifier, QGLViewer::CAMERA, QGLViewer::ZOOM);
 
-  setMouseBinding(Qt::ShiftButton | Qt::LeftButton,  QGLViewer::FRAME, QGLViewer::ROTATE,    false);
-  setMouseBinding(Qt::ShiftButton | Qt::RightButton, QGLViewer::FRAME, QGLViewer::TRANSLATE, false);
-  setMouseBinding(Qt::ShiftButton | Qt::MidButton,   QGLViewer::FRAME, QGLViewer::ZOOM,      false);
-  setWheelBinding(Qt::ShiftButton,                   QGLViewer::FRAME, QGLViewer::ZOOM,      false);
-#else
-  setHandlerKeyboardModifiers(QGLViewer::CAMERA, Qt::AltModifier);
-  setHandlerKeyboardModifiers(QGLViewer::FRAME, Qt::NoModifier);
-  setHandlerKeyboardModifiers(QGLViewer::CAMERA, Qt::ControlModifier);
+  setMouseBinding(Qt::NoModifier, Qt::LeftButton, QGLViewer::FRAME, QGLViewer::ROTATE);
+  setMouseBinding(Qt::NoModifier, Qt::RightButton, QGLViewer::FRAME, QGLViewer::TRANSLATE);
+  setMouseBinding(Qt::NoModifier, Qt::MidButton, QGLViewer::FRAME, QGLViewer::ZOOM);
+  setWheelBinding(Qt::NoModifier, QGLViewer::FRAME, QGLViewer::ZOOM);
 
-  setMouseBinding(Qt::ShiftModifier | Qt::LeftButton,  QGLViewer::FRAME, QGLViewer::ROTATE,    false);
-  setMouseBinding(Qt::ShiftModifier | Qt::RightButton, QGLViewer::FRAME, QGLViewer::TRANSLATE, false);
-  setMouseBinding(Qt::ShiftModifier | Qt::MidButton,   QGLViewer::FRAME, QGLViewer::ZOOM,      false);
-  setWheelBinding(Qt::ShiftModifier,                   QGLViewer::FRAME, QGLViewer::ZOOM,      false);
-#endif
+  setMouseBinding(Qt::ShiftModifier, Qt::LeftButton, QGLViewer::FRAME, QGLViewer::ROTATE, false);
+  setMouseBinding(Qt::ShiftModifier, Qt::RightButton, QGLViewer::FRAME, QGLViewer::TRANSLATE, false);
+  setMouseBinding(Qt::ShiftModifier, Qt::MidButton, QGLViewer::FRAME, QGLViewer::ZOOM, false);
+  setWheelBinding(Qt::ShiftModifier, QGLViewer::FRAME, QGLViewer::ZOOM, false);
 
   setAxisIsDrawn();
 
@@ -125,21 +116,21 @@ void Viewer::draw()
   const float nbSteps = 200.0;
   glBegin(GL_QUAD_STRIP);
   for (float i=0; i<nbSteps; ++i)
-    {
-      float ratio = i/nbSteps;
-      float angle = 21.0*ratio;
-      float c = cos(angle);
-      float s = sin(angle);
-      float r1 = 1.0 - 0.8*ratio;
-      float r2 = 0.8 - 0.8*ratio;
-      float alt = ratio - 0.5;
-      const float nor = .5;
-      const float up = sqrt(1.0-nor*nor);
-      glColor3f(1-ratio, 0.2f , ratio);
-      glNormal3f(nor*c*scale, up*scale, nor*s*scale);
-      glVertex3f(r1*c, alt, r1*s);
-      glVertex3f(r2*c, alt+0.05, r2*s);
-    }
+	{
+	  float ratio = i/nbSteps;
+	  float angle = 21.0*ratio;
+	  float c = cos(angle);
+	  float s = sin(angle);
+	  float r1 = 1.0 - 0.8*ratio;
+	  float r2 = 0.8 - 0.8*ratio;
+	  float alt = ratio - 0.5;
+	  const float nor = .5;
+	  const float up = sqrt(1.0-nor*nor);
+	  glColor3f(1-ratio, 0.2f , ratio);
+	  glNormal3f(nor*c*scale, up*scale, nor*s*scale);
+	  glVertex3f(r1*c, alt, r1*s);
+	  glVertex3f(r2*c, alt+0.05, r2*s);
+	}
   glEnd();
 
   displayText();
@@ -148,19 +139,19 @@ void Viewer::draw()
 void Viewer::keyPressEvent(QKeyEvent *e)
 {
   switch (e->key())
-    {
-    case Qt::Key_G : transDir = (transDir+1)%3; break;
-    case Qt::Key_D : rotDir   = (rotDir+1)%3;   break;
-    case Qt::Key_Space: changeConstraint();     break;
-    case Qt::Key_T :
-      constraints[activeConstraint]->setTranslationConstraintType(nextTranslationConstraintType(constraints[activeConstraint]->translationConstraintType()));
-      break;
-    case Qt::Key_R :
-      constraints[activeConstraint]->setRotationConstraintType(nextRotationConstraintType(constraints[activeConstraint]->rotationConstraintType()));
-      break;
-    default:
-      QGLViewer::keyPressEvent(e);
-    }
+	{
+	case Qt::Key_G : transDir = (transDir+1)%3; break;
+	case Qt::Key_D : rotDir   = (rotDir+1)%3;   break;
+	case Qt::Key_Space: changeConstraint();     break;
+	case Qt::Key_T :
+	  constraints[activeConstraint]->setTranslationConstraintType(nextTranslationConstraintType(constraints[activeConstraint]->translationConstraintType()));
+	  break;
+	case Qt::Key_R :
+	  constraints[activeConstraint]->setRotationConstraintType(nextRotationConstraintType(constraints[activeConstraint]->rotationConstraintType()));
+	  break;
+	default:
+	  QGLViewer::keyPressEvent(e);
+	}
 
   Vec dir(0.0,0.0,0.0);
   dir[transDir] = 1.0;
@@ -177,12 +168,12 @@ void Viewer::displayType(const AxisPlaneConstraint::Type type, const int x, cons
 {
   QString text;
   switch (type)
-    {
-    case AxisPlaneConstraint::FREE:  text = QString("FREE (%1)").arg(c);  break;
-    case AxisPlaneConstraint::PLANE: text = QString("PLANE (%1)").arg(c); break;
-    case AxisPlaneConstraint::AXIS:  text = QString("AXIS (%1)").arg(c); break;
-    case AxisPlaneConstraint::FORBIDDEN: text = QString("FORBIDDEN (%1)").arg(c); break;
-    }
+	{
+	case AxisPlaneConstraint::FREE:  text = QString("FREE (%1)").arg(c);  break;
+	case AxisPlaneConstraint::PLANE: text = QString("PLANE (%1)").arg(c); break;
+	case AxisPlaneConstraint::AXIS:  text = QString("AXIS (%1)").arg(c); break;
+	case AxisPlaneConstraint::FORBIDDEN: text = QString("FORBIDDEN (%1)").arg(c); break;
+	}
   drawText(x, y, text);
 }
 
@@ -190,11 +181,11 @@ void Viewer::displayDir(const unsigned short dir, const int x, const int y, cons
 {
   QString text;
   switch (dir)
-    {
-    case 0: text = QString("X (%1)").arg(c); break;
-    case 1: text = QString("Y (%1)").arg(c); break;
-    case 2: text = QString("Z (%1)").arg(c); break;
-    }
+	{
+	case 0: text = QString("X (%1)").arg(c); break;
+	case 1: text = QString("Y (%1)").arg(c); break;
+	case 2: text = QString("Z (%1)").arg(c); break;
+	}
   drawText(x, y, text);
 }
 
@@ -211,11 +202,11 @@ void Viewer::displayText()
   displayType(constraints[activeConstraint]->rotationConstraintType(), width()-220, height()-60, 'R');
 
   switch (activeConstraint)
-    {
-    case 0 : drawText(20,20, "Constraint direction defined w/r to LOCAL (SPACE)"); break;
-    case 1 : drawText(20,20, "Constraint direction defined w/r to WORLD (SPACE)"); break;
-    case 2 : drawText(20,20, "Constraint direction defined w/r to CAMERA (SPACE)"); break;
-    }
+	{
+	case 0 : drawText(20,20, "Constraint direction defined w/r to LOCAL (SPACE)"); break;
+	case 1 : drawText(20,20, "Constraint direction defined w/r to WORLD (SPACE)"); break;
+	case 2 : drawText(20,20, "Constraint direction defined w/r to CAMERA (SPACE)"); break;
+	}
   glEnable(GL_LIGHTING);
 }
 
@@ -227,7 +218,7 @@ QString Viewer::helpString() const
   text += "(<b>D</b> and <b>R</b>) constraints while moving the frame with the mouse.<br><br>";
   text += "The constraints can be defined with respect to various coordinates";
   text += "systems : press <b>Space</b> to switch.<br><br>";
-  text += "Press the <b>Control</b> key while moving the mouse to move the camera.<br>";
+  text += "Press the <b>Alt</b> key while moving the mouse to move the camera.<br>";
   text += "Press the <b>Shift</b> key to temporally disable the constraint.<br><br>";
   text += "You can easily define your own constraints to create a specific frame behavior.";
   return text;
