@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.4.
+ This file is part of the QGLViewer library version 2.5.3.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,7 +22,7 @@
 
 #include <fstream>
 #include <stdio.h>
-#include "board.h"
+#include "../Viewer/board.h"
 
 int main (int argc, char ** argv)
 {    
