@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.4.
+ This file is part of the QGLViewer library version 2.5.3.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -41,7 +41,7 @@ public:
   AgoraViewer(QWidget* parent=NULL);
 #endif
   
-public slots:
+public Q_SLOTS:
   // F i l e   m e n u
   void load();
   void save();
@@ -75,7 +75,7 @@ protected :
   
   void play(const Move& m);
 
-private slots:
+private Q_SLOTS:
   void simplePlay();
   void playComputerMove(QString move, int duration);
   void playNextMove();
