@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.4.
+ This file is part of the QGLViewer library version 2.5.3.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -51,10 +51,10 @@ public:
   void play(bool black, const QString& stateFileName, int nbMovesLeft);
 
 public:
-  signals:
+  Q_SIGNALS:
   void moveMade(QString move, int duration);
  
-private slots:
+private Q_SLOTS:
   void selectProgram();
   void readFromStdout();
   
