@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.4.
+ This file is part of the QGLViewer library version 2.5.3.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -29,8 +29,8 @@
 #include "qprocess.h"
 
 #if QT_VERSION >= 0x040000
+# include "ui_computerPlayerInterface.h"
 # include <QTime>
-# include "ui_computerPlayerInterface.Qt4.h"
   class ComputerPlayerInterface : public QDialog, public Ui::ComputerPlayerInterface
   {
   public:
@@ -165,7 +165,7 @@ void ComputerPlayer::readFromStdout()
 #else
   QString result = QString((process_->readAllStandardOutput()).trimmed());
 #endif
-  emit moveMade(result, duration);
+  Q_EMIT moveMade(result, duration);
 #if QT_VERSION < 0x040000
   delete process_;
 #else
