@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.4.
+ This file is part of the QGLViewer library version 2.5.3.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -769,7 +769,7 @@ void EventRecorder::replayNextEvent()
 	  qglviewer()->updateGL();
 	  break;
 	case QEvent::User:
-	  emit replayCustomEvent((int)(eventRecords_[nextReplayEvent_].event.frameState));
+	  Q_EMIT replayCustomEvent((int)(eventRecords_[nextReplayEvent_].event.frameState));
 	  break;
 	default:
 	  qWarning("Unknown event type " + QString::number(eventRecords_[nextReplayEvent_].type));
