@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.4.
+ This file is part of the QGLViewer library version 2.5.3.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -21,7 +21,6 @@
 *****************************************************************************/
 
 // TP OpenGL: Joerg Liebelt, Serigne Sow
-#include <stdio.h>
 #include "quadtree.h"
 
 #define SQR( number )		( number*number )
@@ -498,7 +497,7 @@ void QUADTREE::RefineNode( float x, float z, int edgeLength )
 			   fabs(pZ-( z *scaleSize /sizeHeightMap ) ) );
 
 
-  //f: valeur qui decide si on subdivise un noeud ou non (selon l'article de Stefan Rttger sur le quadtree algo)
+  //f: valeur qui decide si on subdivise un noeud ou non (selon l'article de Stefan Röttger sur le quadtree algo)
   f= viewDistance/( ( float )edgeLength*minResolution*	/*/sizeHeightMap* */
 		    MAX( ( float )GetQuadMatrixData( ( int )x-1, ( int )z )/3*detailLevel, 1.0f ) );
   if (debugger) printf("f: %f\n",f);
@@ -806,7 +805,7 @@ void QUADTREE::RenderNode( float x, float z, int edgeLength, bool multiTextures,
 	    }
 
 	  //il reste les suites partielles a afficher; on utilise les codes pour faciliter le choix de triang.
-	  //cette partie est quasiment directement copie de l'article de Stefan Rttger;
+	  //cette partie est quasiment directement copie de l'article de Stefan Röttger;
 	  //.. les codes des suites partielles sont pas evidents.. (code binaire pour representer un quadtree)
 	  //suite partielle = repartition non-symmetrique entre enfants recursifs et feuilles
 	  start= suiteStart[code];
