@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2011 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.17.
+ This file is part of the QGLViewer library version 2.5.3.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,17 +22,13 @@
 
 #include <qapplication.h>
 
-#if QT_VERSION >= 0x040000
-# include "ui_viewerInterface.Qt4.h"
-  class ViewerInterface : public QDialog, public Ui::Dialog
-  {
-  public:
-    ViewerInterface() { setupUi(this); }
-  };
-#else
-# include "interface.h"
-# include "viewerInterface.Qt3.h"
-#endif
+#include "ui_viewerInterface.h"
+
+class ViewerInterface : public QDialog, public Ui::Dialog
+{
+public:
+	ViewerInterface() { setupUi(this); }
+};
 
 int main(int argc, char** argv)
 {
@@ -40,11 +36,7 @@ int main(int argc, char** argv)
 
   ViewerInterface vi;
 
-#if QT_VERSION < 0x040000
-  application.setMainWidget(&vi);
-#else
   vi.setWindowTitle("interface");
-#endif
 
   vi.show();
 
