@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.4.
+ This file is part of the QGLViewer library version 2.5.3.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -33,11 +33,7 @@ protected :
 private :
   void drawSaucer() const;
 
-#if WIN32 && QT_VERSION < 0x030000
-# define nbSaucers 10
-#else
   static const int nbSaucers = 10;
-#endif
   qglviewer::Frame saucerPos[nbSaucers];
   QColor saucerColor[nbSaucers];
 };
